==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/panel/translations/razor-panel_da_DK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="da_DK">
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../configpaneldialog.ui" line="14"/>
        <source>Configure panel</source>
        <translation>Panelindstillinger</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="20"/>
        <source>Panel size</source>
        <translation>Panelstørrelse</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="26"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="33"/>
        <location filename="../configpaneldialog.ui" line="115"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="43"/>
        <source>Use theme size</source>
        <translation>Brug temastandard</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="60"/>
        <source>Panel lenght &amp; position</source>
        <translation>Panel længde og position</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="73"/>
        <source>Length:</source>
        <translation>Længde:</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="80"/>
        <source>Alignment:</source>
        <translation>Tilpasning:</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="91"/>
        <source>Left</source>
        <translation>Venstrestillet</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="96"/>
        <source>Center</source>
        <translation>Midterstillet</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="101"/>
        <source>Right</source>
        <translation>Højrestillet</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="110"/>
        <source>%</source>
        <translation>%</translation>
    </message>
</context>
<context>
    <name>PositionAction</name>
    <message>
        <location filename="../razorpanel.cpp" line="578"/>
        <source>Top of desktop</source>
        <translation>Toppen af skrivebordet</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="579"/>
        <source>Bottom of desktop</source>
        <translation>Bunden af skrivebordet</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="580"/>
        <source>Left of desktop</source>
        <translation>Venstre side af skrivebordet</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="581"/>
        <source>Right of desktop</source>
        <translation>Højre side af skrivebordet</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="588"/>
        <source>Top of desktop %1</source>
        <translation>Toppen af skrivebord %1</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="589"/>
        <source>Bottom of desktop %1</source>
        <translation>Bunden af skrivebord %1</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="590"/>
        <source>Left of desktop %1</source>
        <translation>Venstre side af skrivebord %1</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="591"/>
        <source>Right of desktop %1</source>
        <translation>Højre side af skrivebord %1</translation>
    </message>
</context>
<context>
    <name>RazorPanelPluginPrivate</name>
    <message>
        <location filename="../razorpanelplugin.cpp" line="149"/>
        <source>Configure</source>
        <translation>Indstil</translation>
    </message>
    <message>
        <location filename="../razorpanelplugin.cpp" line="154"/>
        <source>Move</source>
        <translation>Flyt</translation>
    </message>
    <message>
        <location filename="../razorpanelplugin.cpp" line="160"/>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
</context>
<context>
    <name>RazorPanelPrivate</name>
    <message>
        <location filename="../razorpanel.cpp" line="832"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="843"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="845"/>
        <source>Add plugins ...</source>
        <translation>Tilføj plugins ...</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="854"/>
        <source>Move plugin</source>
        <translation>Flyt plugin</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="860"/>
        <source>Configure plugin</source>
        <translation>Indstil plugin</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="867"/>
        <source>Delete plugin</source>
        <translation>Slet plugin</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="874"/>
        <source>Show this panel at</source>
        <translation>Vis dette panel i</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="917"/>
        <source>Configure panel</source>
        <translation>Indstil panel</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/panel/translations/razor-panel_da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <source>Configure panel</source>
        <translation>Panelindstillinger</translation>
    </message>
    <message>
        <source>Panel size</source>
        <translation>Panelstørrelse</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <source>Use automatic sizing</source>
        <translation>Brug automatisk dimensionering</translation>
    </message>
    <message>
        <source>Panel length &amp;&amp; position</source>
        <translation>Panel længde &amp;&amp; position</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Venstrestillet</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>Midterstillet</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Højrestillet</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Alignment:</source>
        <translation>Tilpasning:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Længde:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Position:</translation>
    </message>
    <message>
        <source>Top of desktop</source>
        <translation>Toppen af skrivebordet</translation>
    </message>
    <message>
        <source>Left of desktop</source>
        <translation>Venstre side af skrivebordet</translation>
    </message>
    <message>
        <source>Right of desktop</source>
        <translation>Højre side af skrivebordet</translation>
    </message>
    <message>
        <source>Bottom of desktop</source>
        <translation>Bunden af skrivebordet</translation>
    </message>
    <message>
        <source>Top of desktop %1</source>
        <translation>Toppen af skrivebord %1</translation>
    </message>
    <message>
        <source>Left of desktop %1</source>
        <translation>Venstre side af skrivebord %1</translation>
    </message>
    <message>
        <source>Right of desktop %1</source>
        <translation>Højre side af skrivebord %1</translation>
    </message>
    <message>
        <source>Bottom of desktop %1</source>
        <translation>Bunden af skrivebord %1</translation>
    </message>
</context>
<context>
    <name>RazorPanel</name>
    <message>
        <source>Panel</source>
        <translation>Hej Verden</translation>
    </message>
    <message>
        <source>Configure panel...</source>
        <translation>Indstil panelet...</translation>
    </message>
    <message>
        <source>Add plugins ...</source>
        <translation>Tilføj plugins ...</translation>
    </message>
</context>
<context>
    <name>RazorPanelPlugin</name>
    <message>
        <source>Configure</source>
        <translation>Indstil</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Flyt</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
</context>
<context>
    <name>RazorPanelPrivate</name>
    <message>
        <source>Configure panel</source>
        <translation>Indstil panel</translation>
    </message>
</context>
</TS>
